"""
Copyright (c) 2015-2020 BurstIQ Inc - All Rights Reserved
Unauthorized copying of this file, via any medium is strictly prohibited.
Proprietary and confidential
"""

from typing import Dict, Optional

import requests


class ApiRunner:
    _DEFAULT_HEADERS = {
        'Content-Type': 'application/json',
        'Content-Accept': 'application/json'
    }

    @staticmethod
    def run_chain_post(api_path: str,
                       request_body: object,
                       auth: Dict) -> requests:
        """
        Post Request using Private ID Auth.
        """
        default_headers = ApiRunner._DEFAULT_HEADERS
        default_headers.update(auth)

        try:
            # issue request
            resp = requests.post(api_path,
                                 json=request_body,
                                 headers=default_headers)

            # print response
            print(f'   status:       {resp.status_code}')
            print(f'   timestamp:    {resp.json().get("timestamp").get("$date")}')
            print(f'   message:      {resp.json().get("message")}')
            return resp

        except Exception as e:
            # catch everything, to prevent the interpreter from being killed
            print(f'ERROR: {e}')

    @staticmethod
    def run_post(api_path: str,
                 request_body: dict,
                 auth: Optional[Dict[str, str]]) -> requests:
        """
        Post Request using Basic Auth.
        """
        default_headers = ApiRunner._DEFAULT_HEADERS

        try:
            # issue request
            resp = requests.post(api_path,
                                 json=request_body,
                                 headers=default_headers,
                                 auth=auth)

            # print response
            print(f'   status:       {resp.status_code}')
            print(f'   timestamp:    {resp.json().get("timestamp").get("$date")}')
            print(f'   message:      {resp.json().get("message")}')
            return resp
        except Exception as e:
            # catch everything, to prevent the interpreter from being killed
            print(f'ERROR: {e}')

    @staticmethod
    def run_get(api_path: str,
                auth: Dict) -> requests:
        """
        Get Request using Basic Auth.
        """
        try:
            # issue request
            resp = requests.get(api_path,
                                headers=ApiRunner._DEFAULT_HEADERS,
                                auth=auth)

            # print response
            print(f'   status:       {resp.status_code}')
            print(f'   timestamp:    {resp.json().get("timestamp").get("$date")}')
            print(f'   message:      {resp.json().get("message")}')
            return resp

        except Exception as e:
            # catch everything, to prevent the interpreter from being killed
            print(f'ERROR: {e}')

    @staticmethod
    def run_chain_get(api_path: str,
                      auth: Dict) -> requests:
        """
        Get Request using Private ID Auth.
        """
        try:
            default_headers = ApiRunner._DEFAULT_HEADERS
            default_headers.update(auth)
            # issue request
            resp = requests.get(api_path,
                                headers=ApiRunner._DEFAULT_HEADERS)

            # print response
            print(f'   status:       {resp.status_code}')
            print(f'   timestamp:    {resp.json().get("timestamp").get("$date")}')
            print(f'   message:      {resp.json().get("message")}')
            return resp

        except Exception as e:
            # catch everything, to prevent the interpreter from being killed
            print(f'ERROR: {e}')
