"""
Copyright (c) 2015-2020 BurstIQ Inc - All Rights Reserved
Unauthorized copying of this file, via any medium is strictly prohibited.
Proprietary and confidential
"""
import os
from argparse import Namespace
from os.path import expanduser
from typing import Dict

from cliq_runner.cliq_properties import AssetType, Target


class Info:

    def __init__(self, username: str, password:  str):
        self._username = username
        self._password = password
        self._asset_type = AssetType.ASSET

        self._url = None
        self._client = None
        self._private_id = None
        self._profile = None

        # Sets Query Language
        self._target = None
        self._input_path = None
        self._output_path = None

    def set_profile_info(self,
                         profile_name: str,
                         profile: Dict) -> None:
        self.set_profile(profile_name)
        self.set_url(profile.get('url'))
        self.set_client(profile.get('client'))
        self.set_private_id(profile.get('private_id'))
        self.set_target(profile.get('target'))
        self.set_input_path(profile.get('input_path'))
        self.set_output_path(profile.get('output_path'))
        self.set_asset_type(profile.get('asset_type'))

    def get_username(self, arg: Namespace = None) -> str:
        if arg and arg.username:
            return arg.username
        else:
            return self._username

    def set_username(self, username: str) -> None:
        self._username = username

    def get_password(self, arg: Namespace = None) -> str:
        if arg and arg.password:
            return arg.password
        else:
            return self._password

    def set_password(self, password: str) -> None:
        self._password = password

    def set_client(self, client: str) -> None:
        self._client = client

    def get_client(self, arg: Namespace = None) -> str:
        if arg and arg.client:
            return arg.client
        else:
            return self._client

    def set_profile(self, profile: str):
        self._profile = profile

    def get_profile(self) -> str:
        return self._profile

    def set_url(self, url: str):
        self._url = url

    def get_url(self, arg: Namespace = None) -> str:
        if arg and arg.url:
            return arg.url
        else:
            return self._url

    def set_private_id(self, private_id: str) -> None:
        self._private_id = private_id

    def get_private_id(self, arg: Namespace = None) -> str:
        if arg and arg.private_id:
            return arg.private_id
        else:
            return self._private_id

    def has_private_id(self) -> bool:
        return self._private_id is not None

    def has_password(self) -> bool:
        return self._password is not None

    def get_target(self) -> Target:
        return self._target

    def set_target(self, target: str) -> None:
        if target:
            self._target = Target[target.upper()]

    def get_target_name(self, arg: Namespace = None):
        if arg and arg.target:
            return arg.target
        else:
            if self._target is not None:
                return self._target.name
            else:
                return None

    def get_input_path(self) -> str:
        return self._input_path

    def set_input_path(self, fp: str) -> None:
        if fp:
            if fp.startswith('~/'):
                home = expanduser('~')
                fp = fp.replace('~/', f'{home}/')

            if os.path.isdir(fp):
                self._input_path = fp
            else:
                print(f'Warning file path: {fp} is not a directory or does not exist; did not set')
                print()
        else:
            print(f'Warning file path: {fp} is not a directory or does not exist; did not set')
            print()

    def set_output_path(self, fn: str) -> None:
        if fn:
            if fn.startswith('~/'):
                home = expanduser('~')
                fn = fn.replace('~/', f'{home}/')

            # if no path exists, prepend the default file path
            if os.path.dirname(fn) == '':
                fn = os.path.join(self._output_path, fn)

            self._output_path = fn
        else:
            print(f'Warning output path: {fn} is not a filename or file path, did not set.')
            print()

    def get_output_path(self) -> str:
        return self._output_path

    def set_asset_type(self, asset_type: str) -> None:
        if asset_type:
            self._asset_type = AssetType[asset_type.upper()]

    def get_asset_type(self) -> AssetType:
        return self._asset_type
