"""
Copyright (c) 2015-2020 BurstIQ Inc - All Rights Reserved
Unauthorized copying of this file, via any medium is strictly prohibited.
Proprietary and confidential
"""

from cmd import Cmd

from cliq_runner.runner_manager import RunnerManager


class SetInterpreter(Cmd):

    def __init__(self,
                 runner: RunnerManager):
        super().__init__()

        self._runner_manager = runner

    def do_help(self, line: str):
        """
        Returns information about the Set sub-commands
        """
        Cmd.doc_header = 'Documented Set sub-commands (type "set help <topic>"):'
        super(SetInterpreter, self).do_help(line)

    def do_target(self, line: str):
        """
        Sets the target data source (IQ or Burstchain)

        Example:
        set target <IQ/BURSTCHAIN>
        """
        if line is None or line == '':
            print(f'Please specify a Target to Set (iq or burstchain)')
        else:
            self._runner_manager.get_info().set_target(line)

    def do_username(self, line: str):
        """
        Sets the username

        Example:
        set username <username>
        """
        if line is None or line == '':
            print('Unable to set username, a username was not provided.')
        else:
            self._runner_manager.get_info().set_username(line)

    def do_password(self, line: str):
        """
        Sets the Session Password

        Example:
        set password <password>
        """
        print('Setting password')
        if line is None or line == '':
            print('Unable to set password, a password was not provided.')
        else:
            self._runner_manager.get_info().set_password(line)

    def do_client(self, line: str):
        """
        Sets the Client name

        Example:
        set client <client_name>
        """
        print('Setting Client')
        if line is None or line == '':
            print('Unable to set client name, a client name was not provided.')
        else:
            self._runner_manager.get_info().set_client(line)

    def do_private_id(self, line: str):
        """
        Sets the Private ID

        Example:
        set private_id <private_id>
        """
        print('Setting Private ID')
        if line is None or line == '':
            print('Unable to set Private ID, a Private ID was not provided.')
        else:
            self._runner_manager.get_info().set_private_id(line)

    def do_host_url(self, line: str):
        """
        Sets the Host Url for the Session

        Example:
        set host_url <host_url>
        """
        if line is None or line == '':
            print('Unable to set host url, a host url was not provided.')
        else:
            print(self._runner_manager.get_info().set_url(line))

    def do_profile(self, line: str):
        """"
                Sets a Profile
                """
        print('Setting Profile')
        self._runner_manager.set_profile(line)

    def do_asset_type(self, line: str):
        """"
        Sets asset type (asset or smart_contract)
        """
        print('Setting Asset Type')
        self._runner_manager.get_info().set_asset_type(line)

    def do_input_path(self, line: str):
        """
        Sets the input file path
        """
        print('Setting Input Path')
        self._runner_manager.get_info().set_input_path(line)

    def do_output_path(self, line: str):
        """
        Sets the output file path
        """
        print('Setting Output Path')
        self._runner_manager.get_info().set_output_path(line)
