"""
Copyright (c) 2015-2020 BurstIQ Inc - All Rights Reserved
Unauthorized copying of this file, via any medium is strictly prohibited.
Proprietary and confidential
"""
from argparse import Namespace

from requests.auth import HTTPBasicAuth

from cliq_runner.cliq_properties import CliqProperties
from cliq_runner.info.info import Info


class RunnerManager:

    @staticmethod
    def get_basic_auth(info: Info, args: Namespace):
        return HTTPBasicAuth(info.get_username(args), info.get_password(args))

    def __init__(self,
                 props: CliqProperties,
                 profile_name: str):

        print("CLIQ is Starting up! Using Runner Manager")
        print()

        self._props = props

        # Set Profile info
        # prompt the user for the profile to get started, unless they specified one on the cmd line
        profile = self._props.get_profile(profile_name)
        while not profile:
            self.get_profiles()
            profile_name = input('Please enter a Profile: ')
            profile = self._props.get_profile(profile_name)

        # Set User Info
        user_info = self._props.get_user_info()
        self._username = user_info.get('username')
        self._password = user_info.get('password')
        self._info = Info(self._username, self._password)
        self._info.set_profile_info(profile_name, profile)

    def get_profiles(self) -> None:
        self._props.get_profiles()

    def get_profile(self, profile_name: str) -> None:
        profile = self._props.get_profile(profile_name)
        print(profile)

    def set_profile(self, profile_name: str) -> None:
        profile = self._props.get_profile(profile_name)
        if profile is None:
            print(f'ERROR: Unable to find profile information for the profile {profile}.')
        elif profile.get('url') is None:
            print(f'ERROR: Unable to find host information for the profile {profile}, the url field must be set for '
                  f'this profile.')
        else:
            self._info.set_profile_info(profile_name, profile)

    def get_info(self) -> Info:
        return self._info

    def print_info(self) -> None:
        print()
        print(f'INFO:')
        print(f'     username:       {self._info.get_username()}')
        print(f'     has password:   {self._info.has_password()}')
        print(f'     profile:        {self._info.get_profile()}')
        print(f'     url:            {self._info.get_url()}')
        print(f'     client:         {self._info.get_client()}')
        print(f'     has private id: {self._info.has_private_id()}')
        print(f'     target:         {self._info.get_target_name()}')
        print(f'     asset_type:     {self._info.get_asset_type()}')
        print()
