"""
Copyright (c) 2015-2020 BurstIQ Inc - All Rights Reserved
Unauthorized copying of this file, via any medium is strictly prohibited.
Proprietary and confidential
"""
import pprint

from cliq_runner.api_runner import ApiRunner
from cliq_runner.runner_manager import RunnerManager


class DictionaryInfo:

    def __init__(self):

        self._dictionary_list = {}
        self._pp = pprint.PrettyPrinter(indent=2)

    def get_dict_list(self,
                      runner_manager: RunnerManager) -> None:
        """
        This prints a list of current dictionary names
        """
        if self._dictionary_list == {}:
            self.query_dict_list(runner_manager)
        for i in self._dictionary_list:
            print(i)

    def get_dict(self, dictionary_name: str,
                 runner_manager: RunnerManager) -> None:
        """
        Prints out the full dictionary
        """
        if self._dictionary_list == {}:
            self.query_dict_list(runner_manager)
        if dictionary_name in self._dictionary_list:
            self._pp.pprint(self._dictionary_list[dictionary_name])
        else:
            print('The dictionary you are looking for does not exists.')

    def query_dict_list(self,
                        runner_manager: RunnerManager) -> None:
        """
        Runs the API call for getting the list of dictionaries
        """
        api_path = f'{runner_manager.get_info().get_url()}/api/metadata/dictionaries'

        resp = ApiRunner.run_get(api_path, runner_manager.get_basic_auth(runner_manager.get_info()))

        if resp.status_code == 200:
            dict_list = resp.json().get('dictionaries')
            print('Dictionaries: ')
            for i in dict_list:
                key = i['collection']
                self._dictionary_list[key] = i
            print()
        else:
            print(f'   error:     {resp.json().get("error")}')
