"""
Copyright (c) 2015-2020 BurstIQ Inc - All Rights Reserved
Unauthorized copying of this file, via any medium is strictly prohibited.
Proprietary and confidential
"""
from argparse import Namespace

from cliq_runner.api_runner import ApiRunner
from cliq_runner.info.info import Info


class PublicPrivate:

    @staticmethod
    def get_public_id(info: Info, args: Namespace) -> None:
        """
        This runs the API call and prints out the resulting Public ID associated to the Private ID in the Authorization.
        """

        path = f'{info.get_url()}/api/burstchain/id/public'

        auth = {
            'Authorization': 'ID ' + info.get_private_id(args)
        }

        resp = ApiRunner.run_chain_get(path, auth)
        # print response
        if resp.status_code == 200:
            print(f'   Public Id:    {resp.json().get("public_id")}')
            print()

        else:
            print(f'ERROR RESPONSE')
            print(f'   error:     {resp.json().get("error")}')
            print()

    @staticmethod
    def generate_private_id(info: Info) -> None:
        """
        Generates a Private ID using the API and saves that Private ID in the User Info.
        """
        # issue request
        path = f'{info.get_url()}/api/burstchain/id/private'

        resp = ApiRunner.run_chain_get(path,
                                       {})

        # print response
        if resp.status_code == 200:
            print(f'   Private ID:    {resp.json().get("private_id")}')
            print('This is a newly generated private ID, please memorize this or write it somewhere safe,'
                  ' you will not be able to recover it.')
            print()

        else:
            print(f'ERROR RESPONSE')
            print(f'   error:     {resp.json().get("error")}')
        print()
